from speak import *

def take_command():
    r = sr.Recognizer()
    with sr.Microphone() as source:
        print('listening...')
        r.pause_threshold = 1
        audio = r.listen(source)

    try:
        print("recognizing...")
        query = r.recognize_google(audio, language="en-in")
        print(f"aaqa said: {query}")

    except Exception as e:
        print("say that again please...")
        return "none"
    return query



import pyttsx3
import speech_recognition as sr
import datetime

engine = pyttsx3.init('sapi5')
voices = engine.getProperty('voices')
engine.setProperty('voice', voices[0].id)

def speak(audio):
    engine.say(audio)
    engine.runAndWait()


from speak import *


def wishMe():
    time = datetime.datetime.now().hour
    if time>=0 and time<=12:
        speak("Good Morning Sir!")
    elif time>=12 and time<=16:
        speak("Good Afternoon Sir!")
    else:
        speak("Good Afternoon Sir!")


from setuptools import setup, find_packages
import codecs
import os

VERSION = "0.0.1"
DESCREPTION = "ABREZ"
LONG_DESCREPTION = "when you'll make jarvis it will help you very much you'll not need to install many modules"

setup(
    name="Abrez",
    version=VERSION,
    author="Abrez",
    author_email="tajwarhuma2015@gmail.com",
    description=DESCREPTION,
    long_description_content_type="text/markdown",
    long_description=LONG_DESCREPTION,
    packages=find_packages(),
    install_requires =['pyttsx3', 'speech_recognition', 'datetime'],
    keywords=['speak', 'wish', 'take_command','python_tutorial', 'jarvis', 'Artificial Intelligence', 'AI', 'Abrez'],
    classifiers=[
        "Development Status :: 1 - Planning",
        "Intended Audience :: Developers",
        "Programming Language :: Python :: 3",
        "Operating System :: Unix",
        "Operating System :: MacOS :: MacOS X",
        "Operating System :: Microsoft :: Windows",
    ]
)